@@ -137,7 +137,7 @@ class HttpMockWithErrors(object):
         elif self.num_errors == 4:
             ex = httplib2.ServerNotFoundError()
         elif self.num_errors == 3:
-            ex = socket.error()
+            ex = OSError()
             ex.errno = socket.errno.EPIPE
         elif self.num_errors == 2:
             ex = ssl.SSLError()
@@ -145,14 +145,14 @@ class HttpMockWithErrors(object):
             # Initialize the timeout error code to the platform's error code.
             try:
                 # For Windows:
-                ex = socket.error()
+                ex = OSError()
                 ex.errno = socket.errno.WSAETIMEDOUT
             except AttributeError:
                 # For Linux/Mac:
                 if PY3:
                     ex = socket.timeout()
                 else:
-                    ex = socket.error()
+                    ex = OSError()
                     ex.errno = socket.errno.ETIMEDOUT
 
         self.num_errors -= 1
@@ -170,14 +170,14 @@ class HttpMockWithNonRetriableErrors(object):
             return httplib2.Response(self.success_json), self.success_data
         else:
             self.num_errors -= 1
-            ex = socket.error()
+            ex = OSError()
             # set errno to a non-retriable value
             try:
                 # For Windows:
-                ex.errno = socket.errno.WSAECONNREFUSED
+                ex.errno = socket.errno.WSAEHOSTUNREACH
             except AttributeError:
                 # For Linux/Mac:
-                ex.errno = socket.errno.ECONNREFUSED
+                ex.errno = socket.errno.EHOSTUNREACH
             # Now raise the correct timeout error.
             raise ex
 
@@ -248,6 +248,10 @@ class TestMediaUpload(unittest.TestCase):
         self.assertEqual(500, new_upload.chunksize())
         self.assertEqual(b"PNG", new_upload.getbytes(1, 3))
 
+    def test_media_file_upload_raises_on_file_not_found(self):
+        with self.assertRaises(FileNotFoundError):
+            MediaFileUpload(datafile("missing.png"))
+
     def test_media_file_upload_raises_on_invalid_chunksize(self):
         self.assertRaises(
             InvalidChunkSizeError,
@@ -473,7 +477,7 @@ class TestMediaIoBaseUpload(unittest.TestCase):
 class TestMediaIoBaseDownload(unittest.TestCase):
     def setUp(self):
         http = HttpMock(datafile("zoo.json"), {"status": "200"})
-        zoo = build("zoo", "v1", http=http)
+        zoo = build("zoo", "v1", http=http, static_discovery=False)
         self.request = zoo.animals().get_media(name="Lion")
         self.fd = BytesIO()
 
@@ -939,7 +943,7 @@ class TestHttpRequest(unittest.TestCase):
         )
         request._sleep = lambda _x: 0  # do nothing
         request._rand = lambda: 10
-        with self.assertRaises(socket.error):
+        with self.assertRaises(OSError):
             response = request.execute(num_retries=3)
 
     def test_retry_connection_errors_non_resumable(self):
